==> openGion_dev_5.9.18.0.zip: opengion/uap/webapps/gf/db/sqlserver/sql/install/01_TABLE/GF28S.sql <==
/****************************************************************************/
/* GF28 ( 対訳ﾃｰﾌﾞﾙ )                                                       */
/*                                                                          */
/* Created : 2016/11/04 10:32:20                                            */
/****************************************************************************/
CREATE TABLE GF28 (
   GENBUN       varchar           ( 500 )                   NOT NULL            /*  10 原文     */
 , LANG_GEN     varchar           (   2 )                   NOT NULL            /*  20 原文言語 */
 , LANG_YAKU    varchar           (   2 )                   NOT NULL            /*  30 訳文言語 */
 , KBYAKU       varchar           (   1 )                   NOT NULL            /*  40 訳文区分 */
 , YAKU         varchar           ( 500 )                                       /*  50 訳文     */
 , ID           varchar           (  30 )                                       /*  60 ID       */
 , COMMENTS     varchar           ( 500 )                                       /*  70 ｺﾒﾝﾄ     */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ          varchar           (   1 )       DEFAULT 1   NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        varchar           (  14 )                                       /* 820 登録日時 */
 , PGSET        varchar           (  10 )                                       /* 830 作成PG   */
 , PGPSET       varchar           (  10 )                                       /* 840 作成親PG */
 , USRSET       varchar           (  10 )                                       /* 850 作成社員 */
 , DYUPD        varchar           (  14 )                                       /* 860 更新日時 */
 , PGUPD        varchar           (  10 )                                       /* 870 更新PG   */
 , PGPUPD       varchar           (  10 )                                       /* 880 更新親PG */
 , USRUPD       varchar           (  10 )                                       /* 890 更新者   */
);

==> openGion_dev_5.9.19.0.zip: opengion/uap/webapps/gf/db/sqlserver/sql/install/01_TABLE/GF28S.sql <==
/****************************************************************************/
/* GF28 ( 対訳ﾃｰﾌﾞﾙ )                                                       */
/*                                                                          */
/* Created : 2017/04/07 09:50:29                                            */
/****************************************************************************/
CREATE TABLE GF28 (
   GENBUN       varchar           ( 500 )                   NOT NULL            /*  10 原文     */
 , LANG_GEN     varchar           (   2 )                   NOT NULL            /*  20 原文言語 */
 , LANG_YAKU    varchar           (   2 )                   NOT NULL            /*  30 訳文言語 */
 , KBYAKU       varchar           (   1 )                   NOT NULL            /*  40 訳文区分 */
 , YAKU         varchar           ( 500 )                                       /*  50 訳文     */
 , ID           varchar           (  30 )                                       /*  60 ID       */
 , COMMENTS     varchar           ( 500 )                                       /*  70 ｺﾒﾝﾄ     */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ          varchar           (   1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        varchar           (  14 )                                       /* 820 登録日時 */
 , PGSET        varchar           (  10 )                                       /* 830 作成PG   */
 , PGPSET       varchar           (  10 )                                       /* 840 作成親PG */
 , USRSET       varchar           (  10 )                                       /* 850 作成社員 */
 , DYUPD        varchar           (  14 )                                       /* 860 更新日時 */
 , PGUPD        varchar           (  10 )                                       /* 870 更新PG   */
 , PGPUPD       varchar           (  10 )                                       /* 880 更新親PG */
 , USRUPD       varchar           (  10 )                                       /* 890 更新者   */
);
